@@ -7,24 +7,28 @@
 #' @seealso \code{\link{\%+replace\%}} and \code{\link{+.gg}}
 #' @export
 #' @examples
-#' qplot(mpg, wt, data = mtcars)
+#' p <- ggplot(mtcars, aes(mpg, wt)) +
+#'   geom_point()
+#' p
 #' old <- theme_set(theme_bw())
-#' qplot(mpg, wt, data = mtcars)
+#' p
 #' theme_set(old)
-#' qplot(mpg, wt, data = mtcars)
+#' p
 #'
 #' old <- theme_update(panel.background = element_rect(colour = "pink"))
-#' qplot(mpg, wt, data = mtcars)
+#' p
 #' theme_set(old)
 #' theme_get()
 #'
-#' qplot(mpg, wt, data=mtcars, colour=mpg) +
-#'   theme(legend.position=c(0.95, 0.95), legend.justification = c(1, 1))
+#' ggplot(mtcars, aes(mpg, wt)) +
+#'   geom_point(aes(color = mpg)) +
+#'   theme(legend.position = c(0.95, 0.95),
+#'         legend.justification = c(1, 1))
 #' last_plot() +
 #'  theme(legend.background = element_rect(fill = "white", colour = "white", size = 3))
 theme_update <- function(...) {
   # Make a call to theme, then add to theme
-  theme_set(theme_get() %+replace% do.call(theme, list(...)))
+  theme_set(theme_get() %+replace% theme(...))
 }
 
 #' Reports whether x is a theme object
@@ -33,7 +37,7 @@ theme_update <- function(...) {
 is.theme <- function(x) inherits(x, "theme")
 
 #' @export
-print.theme <- function(x, ...) str(x)
+print.theme <- function(x, ...) utils::str(x)
 
 #' Set theme elements
 #'
@@ -58,12 +62,13 @@ print.theme <- function(x, ...) str(x)
 #' \tabular{ll}{
 #'   line             \tab all line elements
 #'                    (\code{element_line}) \cr
-#'   rect             \tab all rectangluar elements
+#'   rect             \tab all rectangular elements
 #'                    (\code{element_rect}) \cr
 #'   text             \tab all text elements
 #'                    (\code{element_text}) \cr
 #'   title            \tab all title elements: plot, axes, legends
 #'                    (\code{element_text}; inherits from \code{text}) \cr
+#'   aspect.ratio     \tab aspect ratio of the panel \cr
 #'
 #'   axis.title       \tab label of axes
 #'                    (\code{element_text}; inherits from \code{text}) \cr
@@ -85,8 +90,6 @@ print.theme <- function(x, ...) str(x)
 #'                    (\code{element_line}; inherits from \code{axis.ticks}) \cr
 #'   axis.ticks.length  \tab length of tick marks
 #'                    (\code{unit}) \cr
-#'   axis.ticks.margin  \tab space between tick mark and tick label
-#'                    (\code{unit}) \cr
 #'   axis.line        \tab lines along axes
 #'                    (\code{element_line}; inherits from \code{line}) \cr
 #'   axis.line.x      \tab line along x axis
@@ -153,6 +156,9 @@ print.theme <- function(x, ...) str(x)
 #'                    (\code{element_line}; inherits from \code{panel.grid.minor}) \cr
 #'   panel.grid.minor.y \tab horizontal minor grid lines
 #'                    (\code{element_line}; inherits from \code{panel.grid.minor}) \cr
+#'   panel.ontop        \tab option to place the panel (background, gridlines)
+#'                           over the data layers.  Usually used with a transparent
+#'                           or blank \code{panel.background}. (\code{logical}) \cr
 #'
 #'   plot.background  \tab background of the entire plot
 #'                    (\code{element_rect}; inherits from \code{rect}) \cr
@@ -170,6 +176,10 @@ print.theme <- function(x, ...) str(x)
 #'                    (\code{element_text}; inherits from \code{strip.text}) \cr
 #'   strip.text.y     \tab facet labels along vertical direction
 #'                    (\code{element_text}; inherits from \code{strip.text}) \cr
+#'   strip.switch.pad.grid \tab space between strips and axes when strips are switched
+#'                    (\code{unit}) \cr
+#'   strip.switch.pad.wrap \tab space between strips and axes when strips are switched
+#'                    (\code{unit}) \cr
 #' }
 #'
 #' @param ... a list of element name, element pairings that modify the
@@ -177,6 +187,7 @@ print.theme <- function(x, ...) str(x)
 #' @param complete set this to TRUE if this is a complete theme, such as
 #'   the one returned \code{by theme_grey()}. Complete themes behave
 #'   differently when added to a ggplot object.
+#' @param validate TRUE to run validate_element, FALSE to bypass checks.
 #'
 #' @seealso \code{\link{+.gg}}
 #' @seealso \code{\link{\%+replace\%}}
@@ -188,13 +199,15 @@ print.theme <- function(x, ...) str(x)
 #' @export
 #' @examples
 #' \donttest{
-#' p <- qplot(mpg, wt, data = mtcars)
+#' p <- ggplot(mtcars, aes(mpg, wt)) +
+#'   geom_point()
 #' p
 #' p + theme(panel.background = element_rect(colour = "pink"))
 #' p + theme_bw()
 #'
 #' # Scatter plot of gas mileage by vehicle weight
-#' p <- ggplot(mtcars, aes(x = wt, y = mpg)) + geom_point()
+#' p <- ggplot(mtcars, aes(wt, mpg)) +
+#'   geom_point()
 #' # Calculate slope and intercept of line of best fit
 #' coef(lm(mpg ~ wt, data = mtcars))
 #' p + geom_abline(intercept = 37, slope = -5)
@@ -207,7 +220,7 @@ print.theme <- function(x, ...) str(x)
 #' # Change the axis labels
 #' # Original plot
 #' p
-#' p + xlab("Vehicle Weight") + ylab("Miles per Gallon")
+#' p + labs(x = "Vehicle Weight", y = "Miles per Gallon")
 #' # Or
 #' p + labs(x = "Vehicle Weight", y = "Miles per Gallon")
 #'
@@ -219,14 +232,14 @@ print.theme <- function(x, ...) str(x)
 #'
 #' # Changing plot look with themes
 #' DF <- data.frame(x = rnorm(400))
-#' m <- ggplot(DF, aes(x = x)) + geom_histogram()
+#' m <- ggplot(DF, aes(x = x)) +
+#'   geom_histogram()
 #' # Default is theme_grey()
 #' m
 #' # Compare with
 #' m + theme_bw()
 #'
 #' # Manipulate Axis Attributes
-#' library(grid) # for unit
 #' m + theme(axis.line = element_line(size = 3, colour = "red", linetype = "dotted"))
 #' m + theme(axis.text = element_text(colour = "blue"))
 #' m + theme(axis.text.y = element_blank())
@@ -236,17 +249,20 @@ print.theme <- function(x, ...) str(x)
 #' m + theme(axis.ticks.length = unit(.85, "cm"))
 #'
 #' # Legend Attributes
-#' z <- ggplot(mtcars, aes(wt, mpg, colour = factor(cyl))) + geom_point()
+#' z <- ggplot(mtcars, aes(wt, mpg)) +
+#'   geom_point(aes(colour = factor(cyl)))
 #' z
 #' z + theme(legend.position = "none")
 #' z + theme(legend.position = "bottom")
 #' # Or use relative coordinates between 0 and 1
 #' z + theme(legend.position = c(.5, .5))
-#  # Add a border to the whole legend
+#' # Add a border to the whole legend
 #' z + theme(legend.background = element_rect(colour = "black"))
 #' # Legend margin controls extra space around outside of legend:
-#' z + theme(legend.background = element_rect(), legend.margin = unit(1, "cm"))
-#' z + theme(legend.background = element_rect(), legend.margin = unit(0, "cm"))
+#' z + theme(legend.background = element_rect(),
+#'           legend.margin = unit(1, "cm"))
+#' z + theme(legend.background = element_rect(),
+#'           legend.margin = unit(0, "cm"))
 #' # Or to just the keys
 #' z + theme(legend.key = element_rect(colour = "black"))
 #' z + theme(legend.key = element_rect(fill = "yellow"))
@@ -265,15 +281,17 @@ print.theme <- function(x, ...) str(x)
 #' z + theme(panel.grid.major = element_line(colour = "blue"))
 #' z + theme(panel.grid.minor = element_line(colour = "red", linetype = "dotted"))
 #' z + theme(panel.grid.major = element_line(size = 2))
-#' z + theme(panel.grid.major.y = element_blank(), panel.grid.minor.y = element_blank())
+#' z + theme(panel.grid.major.y = element_blank(),
+#'           panel.grid.minor.y = element_blank())
 #' z + theme(plot.background = element_rect())
 #' z + theme(plot.background = element_rect(fill = "green"))
 #'
 #' # Faceting Attributes
 #' set.seed(4940)
 #' dsmall <- diamonds[sample(nrow(diamonds), 1000), ]
-#' k <- ggplot(dsmall, aes(carat, ..density..)) + geom_histogram(binwidth = 0.2) +
-#' facet_grid(. ~ cut)
+#' k <- ggplot(dsmall, aes(carat, ..density..)) +
+#'   geom_histogram(binwidth = 0.2) +
+#'   facet_grid(. ~ cut)
 #' k + theme(strip.background = element_rect(colour = "purple", fill = "pink",
 #'                                           size = 3, linetype = "dashed"))
 #' k + theme(strip.text.x = element_text(colour = "red", angle = 45, size = 10,
@@ -281,6 +299,17 @@ print.theme <- function(x, ...) str(x)
 #' k + theme(panel.margin = unit(5, "lines"))
 #' k + theme(panel.margin.y = unit(0, "lines"))
 #'
+#' # Put gridlines on top
+#' meanprice <- tapply(diamonds$price, diamonds$cut, mean)
+#' cut <- factor(levels(diamonds$cut), levels = levels(diamonds$cut))
+#' df <- data.frame(meanprice, cut)
+#' g <- ggplot(df, aes(cut, meanprice)) + geom_bar(stat = "identity")
+#' g + geom_bar(stat = "identity") +
+#'     theme(panel.background = element_blank(),
+#'           panel.grid.major.x = element_blank(),
+#'           panel.grid.minor.x = element_blank(),
+#'           panel.grid.minor.y = element_blank(),
+#'           panel.ontop = TRUE)
 #'
 #' # Modify a theme and save it
 #' mytheme <- theme_grey() + theme(plot.title = element_text(colour = "red"))
@@ -301,7 +330,7 @@ print.theme <- function(x, ...) str(x)
 #'       data.frame(child = name, parent = item$inherit)
 #'   }
 #'
-#'   edges <- rbind.fill(mapply(inheritdf, names(tree), tree))
+#'   edges <- plyr::rbind.fill(mapply(inheritdf, names(tree), tree))
 #'
 #'   # Explicitly add vertices (since not all are in edge list)
 #'   vertices <- data.frame(name = names(tree))
@@ -316,43 +345,25 @@ print.theme <- function(x, ...) str(x)
 #' plot(g, layout=layout.fruchterman.reingold, vertex.size=4, vertex.label.dist=.25)
 #'
 #' }
-theme <- function(..., complete = FALSE) {
+theme <- function(..., complete = FALSE, validate = TRUE) {
   elements <- list(...)
 
-  # Check that all elements have the correct class (element_text, unit, etc)
-  mapply(validate_element, elements, names(elements))
-
-  structure(elements, class = c("theme", "gg"), complete = complete)
-}
-
-
-#' Build a theme (or partial theme) from theme elements
-#'
-#' \code{opts} is deprecated. See the \code{\link{theme}} function.
-#' @param ... Arguments to be passed on to the \code{theme} function.
-#'
-#' @export
-opts <- function(...) {
-  gg_dep("0.9.1", "'opts' is deprecated. Use 'theme' instead.")
-
-  # Add check for deprecated elements
-  extra <- NULL
-  elements <- list(...)
-  if (!is.null(elements[["title"]])) {
-    # This is kind of a hack, but fortunately it will be removed in future versions
-    gg_dep("0.9.1", paste(sep = "\n",
-      'Setting the plot title with opts(title="...") is deprecated.',
-      ' Use labs(title="...") or ggtitle("...") instead.'))
-
-    title <- elements$title
-    elements$title <- NULL
-
-    return(list(ggtitle(title), do.call(theme, elements)))
+  if (!is.null(elements$axis.ticks.margin)) {
+    warning("`axis.ticks.margin` is deprecated. Please set `margin` property ",
+      " of `axis.text` instead", call. = FALSE)
+    elements$axis.ticks.margin <- NULL
   }
 
-  do.call(theme, elements)
+  # Check that all elements have the correct class (element_text, unit, etc)
+  if (validate) {
+    mapply(validate_element, elements, names(elements))
+  }
+
+  structure(elements, class = c("theme", "gg"),
+            complete = complete, validate = validate)
 }
 
+
 # Combine plot defaults with current theme to get complete theme for a plot
 plot_theme <- function(x) {
   defaults(x$theme, theme_get())
@@ -425,7 +436,7 @@ add_theme <- function(t1, t2, t2name) {
       # If x is NULL or element_blank, then just assign it y
       x <- y
     } else if (is.null(y) || is.character(y) || is.numeric(y) ||
-               inherits(y, "element_blank")) {
+               is.logical(y) || inherits(y, "element_blank")) {
       # If y is NULL, or a string or numeric vector, or is element_blank, just replace x
       x <- y
     } else {
@@ -464,7 +475,8 @@ add_theme <- function(t1, t2, t2name) {
 # same name as those from newtheme, and puts them in oldtheme. Then
 # it adds elements from newtheme to oldtheme.
 # This makes it possible to do things like:
-#   qplot(1:3, 1:3) + theme(text = element_text(colour = 'red'))
+#   ggplot(data.frame(x = 1:3, y = 1:3)) +
+#   geom_point() + theme(text = element_text(colour = 'red'))
 # and have 'text' keep properties from the default theme. Otherwise
 # you would have to set all the element properties, like family, size,
 # etc.
@@ -480,7 +492,7 @@ update_theme <- function(oldtheme, newtheme) {
 
   # These are elements in newtheme that aren't already set in oldtheme.
   # They will be pulled from the default theme.
-  newitems <- ! names(newtheme) %in% names(oldtheme)
+  newitems <- !names(newtheme) %in% names(oldtheme)
   newitem_names <- names(newtheme)[newitems]
   oldtheme[newitem_names] <- theme_get()[newitem_names]
 
@@ -488,59 +500,15 @@ update_theme <- function(oldtheme, newtheme) {
   # Turn the 'theme' list into a proper theme object first, and preserve
   # the 'complete' attribute. It's possible that oldtheme is an empty
   # list, and in that case, set complete to FALSE.
+  old.validate <- isTRUE(attr(oldtheme, "validate"))
+  new.validate <- isTRUE(attr(newtheme, "validate"))
   oldtheme <- do.call(theme, c(oldtheme,
-    complete = isTRUE(attr(oldtheme, "complete"))))
+    complete = isTRUE(attr(oldtheme, "complete")),
+    validate = old.validate & new.validate))
 
   oldtheme + newtheme
 }
 
-
-##' Update contents of a theme. (Deprecated)
-##'
-##' This function is deprecated. Use \code{\link{\%+replace\%}} or
-##' \code{\link{+.gg}} instead.
-##'
-##' @title Update theme param
-##' @param name name of a theme element
-##' @param ... Pairs of name and value of theme parameters.
-##' @return Updated theme element
-##' @seealso \code{\link{\%+replace\%}} and \code{\link{+.gg}}
-##' @export
-##' @examples
-##' \dontrun{
-##' x <- element_text(size = 15)
-##' update_element(x, colour = "red")
-##' # Partial matching works
-##' update_element(x, col = "red")
-##' # So does positional
-##' update_element(x, "Times New Roman")
-##' # And it throws an error if you use an argument that doesn't exist
-##' update_element(x, noargument = 12)
-##' # Or multiple arguments with the same name
-##' update_element(x, size = 12, size = 15)
-##'
-##' # Will look up element if given name
-##' update_element("axis.text.x", colour = 20)
-##' # Throws error if incorrectly named
-##' update_element("axis.text", colour = 20)
-##' }
-update_element <- function(name, ...) {
-  gg_dep("0.9.1", "update_element is deprecated. Use '+.gg' instead.")
- if (is.character(name)) {
-   ele <- theme_get()[[name]]
-   if (is.null(ele)) {
-     stop("Could not find theme element ", name, call. = FALSE)
-   }
- } else {
-   ele <- name
- }
-
-  stopifnot(inherits(ele, "element"))
-
-  modifyList(ele, list(...))
-}
-
-
 #' Calculate the element properties, by inheriting properties from its parents
 #'
 #' @param element The name of the theme element to calculate
